@@ -25,7 +25,7 @@ var languageNames = {
 "fr": "Fransk",
 "gl": "Galisisk",
 "gu": "Gujarati",
-"he": "Hebreisk",
+"he": "Hebraisk",
 "hi": "Hindi",
 "hr": "Kroatisk",
 "hu": "Ungarsk",
